"""Build the correct turn of phrase in Russian"""

__all__ = [
    'ruphrase',
]
__version__ = '0.0.3'

from ruphrase.functions import *
